#!/bin/bash

# This is our script which delays userdata script start while mk-node-adm is installing components through apt.
# Script is using by ansible on the image building stage.
# Ansible moves script from /etc/mk-node-adm/templates to /var/lib/cloud/scripts/per-instance directory
# and than cloud-init executes it before userdata script.


echo "Running script $0"

res=$(hostname | grep -E "node-.{5}" | wc -l)
if [[ $res -lt 1 ]]; then
    echo "No need to wait msg from mk-node-adm socket, it is first image building boot"
    exit 0
fi

socket_path="/var/run/mk-node-adm/unix.sock"

# Make directory for socket if not exists
mkdir -p /var/run/mk-node-adm

teardown() {
    rm $socket_path
    if [[ $? -ne 0 ]]; then
        echo "Failed to remove socket"
        exit 1
    fi
}

success_msg="SUCCESS"
fail_msg="FAIL"

# After this msg we can unlock and start user data script
mknodeadm_msg=$(timeout -k 5s 15m nc -Ul $socket_path)

if [ "$mknodeadm_msg" = "$success_msg" ]; then
	exit_msg="mk-node-adm finished pkg installation, we can continue"
	exit_code=0
elif [ "$mknodeadm_msg" = "$fail_msg" ]; then
	exit_msg="mk-node-adm failed to install node components"
	exit_code=1
elif [ -z "$mknodeadm_msg" ]; then
	exit_msg="No messages received from mk-node-adm, timeout exceeded"
	exit_code=1
else
	exit_msg="Invalid msg received from mk-node-adm, msg = '$mknodeadm_msg'"
	exit_code=1
fi

echo $exit_msg
teardown
exit $exit_code
